pub trait GeneralApi {
// Required methods
fn api_test(&mut self) -> Result<String>;
fn availability_zones(&mut self) -> Result<Vec<AvailabilityZone>>;
fn products(&mut self) -> Result<Products>;
fn product_elements(&mut self, name: &str) -> Result<Vec<ProductElement>>;
}Expand description
Required Methods
Sourcefn api_test(&mut self) -> Result<String>
fn api_test(&mut self) -> Result<String>
See https://api.transip.nl/rest/docs.html#general-apitest-get
The positive result of this method should always be pong.
You can use the demo token.
Sourcefn availability_zones(&mut self) -> Result<Vec<AvailabilityZone>>
fn availability_zones(&mut self) -> Result<Vec<AvailabilityZone>>
See https://api.transip.nl/rest/docs.html#general-availabilityzone-get
The positive result of this method should always be pong.
You can use the demo token.
Example
use transip::{api::general::GeneralApi, Client};
let zones = Client::demo().availability_zones().unwrap();